@@ -12,7 +12,6 @@ MainWindow::MainWindow(QWidget *parent) :
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
     ui->scrollArea->setWidget(ui->widget);
-
     QString varattu3;
     varattu3 = tr("Reading settings");
     progress3.setWindowModality(Qt::WindowModal);
@@ -22,7 +21,7 @@ MainWindow::MainWindow(QWidget *parent) :
     progress3.show();
     progress3.setValue(5);
     readdirs();
-    oldfonts();
+    oldfonts("/etc/hildon/theme/colors.config");
     progress3.setValue(20);
     readSettings();
     progress3.setValue(30);
@@ -60,10 +59,10 @@ MainWindow::~MainWindow()
     delete ui;
 }
 
-void MainWindow::oldfonts()
+void MainWindow::oldfonts(QString preset)
 {
 
-    QFile file("/etc/hildon/theme/colors.config");
+    QFile file(preset);
     file.open(QFile::ReadOnly);
 
     QTextStream stream ( &file );
@@ -319,7 +318,7 @@ void MainWindow::processFinished(int)
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
     system("/sbin/launchcustomizer rebootnow");
     progress.cancel();
-    oldfonts();
+    // oldfonts();
 
 }
 
@@ -612,3 +611,68 @@ void MainWindow::on_actionChange_backgrounds_triggered()
 
     newWin->show();
 }
+
+void MainWindow::on_pushButton_3_clicked()
+{
+    SaveWin = new savepreset(this);
+    connect(SaveWin->ui->Save, SIGNAL(clicked()), this, SLOT(savedone()));
+    SaveWin->show();
+}
+
+void MainWindow::savedone()
+{
+    QString presetname = SaveWin->ui->FileName->text();
+    presetname.remove(QChar('\"'));
+    presetname.remove(QChar(' '));
+    presetname.simplified();
+    if (presetname.isEmpty()) {
+ //       system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'You must give name for the preset' uint32:0 string:'OK'");
+
+        QMaemo5InformationBox::information(this, "You must give name for the preset.",
+                                           QMaemo5InformationBox::DefaultTimeout);
+
+    } else {
+        QFile file("/opt/theme-customizer/presets/" + presetname);
+        if (file.exists()) file.remove();
+        file.open(QIODevice::WriteOnly | QIODevice::Text);
+        QTextStream out(&file);
+        out << "DefaultTextColor=" << f1 << "\n" << "SecondaryTextColor=" << f2 << "\n" << "ActiveTextColor=" << f3 << "\n" << "DisabledTextColor=" << f4 << "\n" << "PaintedTextColor=" << f5 << "\n" << "SelectionColor=" << f6 << "\n" << "ButtonTextColor=" << f7 << "\n" << "ButtonTextPressedColor=" << f8 << "\n";
+
+        // optional, as QFile destructor will already do it:
+        file.close();
+        SaveWin->hide();
+        QMaemo5InformationBox::information(this, "Preset saved!",
+                                           QMaemo5InformationBox::DefaultTimeout);
+    }
+}
+
+void MainWindow::on_pushButton_4_clicked()
+{
+    ManWin = new managepresets(this);
+  //  connect(ManWin->ui->presetslist, SIGNAL(currentIndexChanged(int)), this, SLOT(on_presetslist_currentIndexChanged(int)));
+    connect(ManWin->ui->loadbutton, SIGNAL(clicked()), this, SLOT(loadclicked()));
+    connect(ManWin->ui->delbutton, SIGNAL(clicked()), this, SLOT(delclicked()));
+    ManWin->show();
+}
+
+void MainWindow::loadclicked()
+{
+    if (!ManWin->ui->presetslist->currentIndex() == 0) {
+    loadpr = "/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentText();
+    } else {
+    loadpr = "/etc/hildon/theme/colors.config";
+    }
+    oldfonts(loadpr);
+    ManWin->hide();
+    QMaemo5InformationBox::information(this, "Preset loaded.",
+                                       QMaemo5InformationBox::DefaultTimeout);
+}
+
+void MainWindow::delclicked()
+{
+    QFile file("/opt/theme-customizer/presets/" + ManWin->ui->presetslist->currentText());
+    if (file.exists()) file.remove();
+    ManWin->hide();
+    QMaemo5InformationBox::information(this, "Preset deleted.",
+                                       QMaemo5InformationBox::DefaultTimeout);
+}
