@@ -8,6 +8,26 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Reading settings...</source>
+        <translation>Ladataan asetuksia...</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Reading settings</source>
+        <translation>Asetusten lataus</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Color presets</source>
+        <translation>Väripresetit</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Save color preset</source>
+        <translation>Tallenna presetti</translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="81"/>
         <source>Font</source>
@@ -221,4 +241,88 @@
         <translation>Tietoja Theme Customizerista</translation>
     </message>
 </context>
+<context>
+    <name>backgrounds</name>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Clock</source>
+        <translation>Kello</translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>App Manager</source>
+        <translation>Sov. hallinta</translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Media Player</source>
+        <translation>Mediasoitin</translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Lockscreen</source>
+        <translation>Lukitusruutu</translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Tap me to change</source>
+        <translation>Kosketa vaihtaaksesi</translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Set image</source>
+        <translation>Aseta kuva</translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Backgrounds</source>
+        <translation>Taustakuvat</translation>
+    </message>
+</context>
+<context>
+    <name>savepreset</name>
+    <message>
+        <location filename="savepreset.ui" line="0"/>
+        <source>Save color preset as...</source>
+        <translation>Tallena väripresetti nimellä...</translation>
+    </message>
+    <message>
+        <location filename="savepreset.ui" line="0"/>
+        <source>Save</source>
+        <translation>Tallenna</translation>
+    </message>
+    <message>
+        <location filename="savepreset.ui" line="0"/>
+        <source>Save color preset</source>
+        <translation>Tallenna väripresetti</translation>
+    </message>
+</context>
+<context>
+    <name>managepresets</name>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Choose color preset:</source>
+        <translation>Valitse presetti:</translation>
+    </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Currently active colors</source>
+        <translation>Nykyiset aktiiviset värit</translation>
+    </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Load</source>
+        <translation>Lataa</translation>
+    </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Delete</source>
+        <translation>Poista</translation>
+    </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Manage color presets</source>
+        <translation>Hallitse väripresettejä</translation>
+    </message>
+</context>
 </TS>
