@@ -221,4 +221,88 @@
         <translation>Om Theme Customizer</translation>
     </message>
 </context>
+<context>
+    <name>backgrounds</name>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Clock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>App Manager</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Media Player</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Lockscreen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Tap me to change</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Set image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.ui" line="0"/>
+        <source>Backgrounds</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>savepreset</name>
+    <message>
+        <location filename="savepreset.ui" line="0"/>
+        <source>Save color preset as...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="savepreset.ui" line="0"/>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="savepreset.ui" line="0"/>
+        <source>Save color preset</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>managepresets</name>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Choose color preset:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Currently active colors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Load</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="managepresets.ui" line="0"/>
+        <source>Manage color presets</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
